@@ -40,4 +40,5 @@ class Model(Base):
         ORM转dict
         :return:
         """
-        return {c.name: getattr(self, c.name, None) for c in self.__table__.columns}
+        columns = [c.name for c in self.__table__.columns] + [name for name, obj in vars(self.__class__).items() if isinstance(obj, property)]
+        return {key: getattr(self, key, None) for key in columns}
